@@ -22,6 +22,7 @@ var asyncMap = require('slide').asyncMap
 var ini = require('ini')
 var writeFile = require('write-file-atomic')
 var packageId = require('./utils/package-id.js')
+var output = require('./utils/output.js')
 
 module.exports = build
 build.usage = 'npm build [<folder>]'
@@ -65,8 +66,7 @@ function build_ (global, didPre, didRB) {
         [linkStuff, pkg, folder, global, didRB],
         [writeBuiltinConf, pkg, folder],
         didPre !== build._noLC && [lifecycle, pkg, 'install', folder],
-        didPre !== build._noLC && [lifecycle, pkg, 'postinstall', folder],
-        didPre !== build._noLC && npm.config.get('npat') && [lifecycle, pkg, 'test', folder]
+        didPre !== build._noLC && [lifecycle, pkg, 'postinstall', folder]
       ],
       cb)
     })
@@ -133,12 +133,10 @@ function shouldWarn (pkg, folder, global, cb) {
 
     // current searched package is the linked package on first call
     if (linkedPkg !== currentPkg) {
-
       // don't generate a warning if it's listed in dependencies
       if (Object.keys(topPkg.dependencies || {})
           .concat(Object.keys(topPkg.devDependencies || {}))
           .indexOf(currentPkg) === -1) {
-
         if (top && pkg.preferGlobal && !global) {
           log.warn('prefer global', packageId(pkg) + ' should be installed with -g')
         }
@@ -213,9 +211,7 @@ function linkBins (pkg, folder, parent, gtop, cb) {
           var out = npm.config.get('parseable')
                   ? dest + '::' + src + ':BINFILE'
                   : dest + ' -> ' + src
-          log.clearProgress()
-          console.log(out)
-          log.showProgress()
+          output(out)
           cb()
         })
       }
